@@ -26,11 +26,12 @@ func TestNewCmdEdit(t *testing.T) {
 	require.NoError(t, err)
 
 	tests := []struct {
-		name     string
-		input    string
-		stdin    string
-		output   EditOptions
-		wantsErr bool
+		name             string
+		input            string
+		stdin            string
+		output           EditOptions
+		expectedBaseRepo ghrepo.Interface
+		wantsErr         bool
 	}{
 		{
 			name:  "no argument",
@@ -47,6 +48,16 @@ func TestNewCmdEdit(t *testing.T) {
 			output:   EditOptions{},
 			wantsErr: true,
 		},
+		{
+			name:  "URL argument",
+			input: "https://example.com/cli/cli/pull/23",
+			output: EditOptions{
+				SelectorArg: "https://example.com/cli/cli/pull/23",
+				Interactive: true,
+			},
+			expectedBaseRepo: ghrepo.NewWithHost("cli", "cli", "example.com"),
+			wantsErr:         false,
+		},
 		{
 			name:  "pull request number argument",
 			input: "23",
@@ -326,6 +337,15 @@ func TestNewCmdEdit(t *testing.T) {
 			assert.Equal(t, tt.output.SelectorArg, gotOpts.SelectorArg)
 			assert.Equal(t, tt.output.Interactive, gotOpts.Interactive)
 			assert.Equal(t, tt.output.Editable, gotOpts.Editable)
+			if tt.expectedBaseRepo != nil {
+				baseRepo, err := gotOpts.BaseRepo()
+				require.NoError(t, err)
+				require.True(
+					t,
+					ghrepo.IsSame(tt.expectedBaseRepo, baseRepo),
+					"expected base repo %+v, got %+v", tt.expectedBaseRepo, baseRepo,
+				)
+			}
 		})
 	}
 }
@@ -334,7 +354,7 @@ func Test_editRun(t *testing.T) {
 	tests := []struct {
 		name      string
 		input     *EditOptions
-		httpStubs func(*httpmock.Registry)
+		httpStubs func(*testing.T, *httpmock.Registry)
 		stdout    string
 		stderr    string
 	}{
@@ -344,8 +364,7 @@ func Test_editRun(t *testing.T) {
 				Detector:    &fd.EnabledDetectorMock{},
 				SelectorArg: "123",
 				Finder: shared.NewMockFinder("123", &api.PullRequest{
-					URL:                "https://github.com/OWNER/REPO/pull/123",
-					AssignedActorsUsed: true,
+					URL: "https://github.com/OWNER/REPO/pull/123",
 				}, ghrepo.New("OWNER", "REPO")),
 				Interactive: false,
 				Editable: shared.Editable{
@@ -392,11 +411,11 @@ func Test_editRun(t *testing.T) {
 				},
 				Fetcher: testFetcher{},
 			},
-			httpStubs: func(reg *httpmock.Registry) {
-				mockRepoMetadata(reg, false)
+			httpStubs: func(t *testing.T, reg *httpmock.Registry) {
+				mockRepoMetadata(reg, mockRepoMetadataOptions{reviewers: true, teamReviewers: false, assignees: true, labels: true, projects: true, milestones: true})
 				mockPullRequestUpdate(reg)
 				mockPullRequestUpdateActorAssignees(reg)
-				mockPullRequestReviewersUpdate(reg)
+				mockPullRequestAddReviewers(reg)
 				mockPullRequestUpdateLabels(reg)
 				mockProjectV2ItemUpdate(reg)
 			},
@@ -408,8 +427,7 @@ func Test_editRun(t *testing.T) {
 				Detector:    &fd.EnabledDetectorMock{},
 				SelectorArg: "123",
 				Finder: shared.NewMockFinder("123", &api.PullRequest{
-					URL:                "https://github.com/OWNER/REPO/pull/123",
-					AssignedActorsUsed: true,
+					URL: "https://github.com/OWNER/REPO/pull/123",
 				}, ghrepo.New("OWNER", "REPO")),
 				Interactive: false,
 				Editable: shared.Editable{
@@ -451,8 +469,8 @@ func Test_editRun(t *testing.T) {
 				},
 				Fetcher: testFetcher{},
 			},
-			httpStubs: func(reg *httpmock.Registry) {
-				mockRepoMetadata(reg, true)
+			httpStubs: func(t *testing.T, reg *httpmock.Registry) {
+				mockRepoMetadata(reg, mockRepoMetadataOptions{assignees: true, labels: true, projects: true, milestones: true})
 				mockPullRequestUpdate(reg)
 				mockPullRequestUpdateActorAssignees(reg)
 				mockPullRequestUpdateLabels(reg)
@@ -465,9 +483,19 @@ func Test_editRun(t *testing.T) {
 			input: &EditOptions{
 				Detector:    &fd.EnabledDetectorMock{},
 				SelectorArg: "123",
-				Finder: shared.NewMockFinder("123", &api.PullRequest{
-					URL:                "https://github.com/OWNER/REPO/pull/123",
-					AssignedActorsUsed: true,
+				Finder: shared.NewMockFinder("123", &api.PullRequest{ // include existing reviewers so removal logic triggers
+					URL: "https://github.com/OWNER/REPO/pull/123",
+					ReviewRequests: api.ReviewRequests{Nodes: []struct{ RequestedReviewer api.RequestedReviewer }{
+						{RequestedReviewer: api.RequestedReviewer{TypeName: "Team", Slug: "core", Organization: struct {
+							Login string `json:"login"`
+						}{Login: "OWNER"}}},
+						{RequestedReviewer: api.RequestedReviewer{TypeName: "Team", Slug: "external", Organization: struct {
+							Login string `json:"login"`
+						}{Login: "OWNER"}}},
+						{RequestedReviewer: api.RequestedReviewer{TypeName: "User", Login: "monalisa"}},
+						{RequestedReviewer: api.RequestedReviewer{TypeName: "User", Login: "hubot"}},
+						{RequestedReviewer: api.RequestedReviewer{TypeName: "User", Login: "dependabot"}},
+					}},
 				}, ghrepo.New("OWNER", "REPO")),
 				Interactive: false,
 				Editable: shared.Editable{
@@ -484,8 +512,9 @@ func Test_editRun(t *testing.T) {
 						Edited: true,
 					},
 					Reviewers: shared.EditableSlice{
-						Remove: []string{"OWNER/core", "OWNER/external", "monalisa", "hubot", "dependabot"},
-						Edited: true,
+						Default: []string{"OWNER/core", "OWNER/external", "monalisa", "hubot", "dependabot"},
+						Remove:  []string{"OWNER/core", "OWNER/external", "monalisa", "hubot", "dependabot"},
+						Edited:  true,
 					},
 					Assignees: shared.EditableAssignees{
 						EditableSlice: shared.EditableSlice{
@@ -513,24 +542,116 @@ func Test_editRun(t *testing.T) {
 				},
 				Fetcher: testFetcher{},
 			},
-			httpStubs: func(reg *httpmock.Registry) {
-				mockRepoMetadata(reg, false)
+			httpStubs: func(t *testing.T, reg *httpmock.Registry) {
+				mockRepoMetadata(reg, mockRepoMetadataOptions{reviewers: true, teamReviewers: false, assignees: true, labels: true, projects: true, milestones: true})
 				mockPullRequestUpdate(reg)
-				mockPullRequestReviewersUpdate(reg)
+				mockPullRequestRemoveReviewers(reg)
 				mockPullRequestUpdateLabels(reg)
 				mockPullRequestUpdateActorAssignees(reg)
 				mockProjectV2ItemUpdate(reg)
 			},
 			stdout: "https://github.com/OWNER/REPO/pull/123\n",
 		},
+		// Conditional team fetching cases
+		{
+			name: "non-interactive add only user reviewers skips team fetch",
+			input: &EditOptions{
+				Detector:    &fd.EnabledDetectorMock{},
+				SelectorArg: "123",
+				Finder:      shared.NewMockFinder("123", &api.PullRequest{URL: "https://github.com/OWNER/REPO/pull/123"}, ghrepo.New("OWNER", "REPO")),
+				Interactive: false,
+				Editable: shared.Editable{
+					Reviewers: shared.EditableSlice{Add: []string{"monalisa", "hubot"}, Edited: true},
+				},
+				Fetcher: testFetcher{},
+			},
+			httpStubs: func(t *testing.T, reg *httpmock.Registry) {
+				// reviewers only (users), no team reviewers fetched
+				mockRepoMetadata(reg, mockRepoMetadataOptions{reviewers: true})
+				// explicitly assert that no OrganizationTeamList query occurs
+				reg.Exclude(t, httpmock.GraphQL(`query OrganizationTeamList\b`))
+				mockPullRequestUpdate(reg)
+				mockPullRequestAddReviewers(reg)
+			},
+			stdout: "https://github.com/OWNER/REPO/pull/123\n",
+		},
+		{
+			name: "non-interactive add contains team reviewers skips team fetch",
+			input: &EditOptions{
+				Detector:    &fd.EnabledDetectorMock{},
+				SelectorArg: "123",
+				Finder:      shared.NewMockFinder("123", &api.PullRequest{URL: "https://github.com/OWNER/REPO/pull/123"}, ghrepo.New("OWNER", "REPO")),
+				Interactive: false,
+				Editable: shared.Editable{
+					Reviewers: shared.EditableSlice{Add: []string{"monalisa", "OWNER/core"}, Edited: true},
+				},
+				Fetcher: testFetcher{},
+			},
+			httpStubs: func(t *testing.T, reg *httpmock.Registry) {
+				// reviewer add includes team but non-interactive Add/Remove provided -> no team fetch
+				mockRepoMetadata(reg, mockRepoMetadataOptions{reviewers: true})
+				// explicitly assert that no OrganizationTeamList query occurs
+				reg.Exclude(t, httpmock.GraphQL(`query OrganizationTeamList\b`))
+				mockPullRequestUpdate(reg)
+				mockPullRequestAddReviewers(reg)
+			},
+			stdout: "https://github.com/OWNER/REPO/pull/123\n",
+		},
+		{
+			name: "non-interactive reviewers remove contains team skips team fetch",
+			input: &EditOptions{
+				Detector:    &fd.EnabledDetectorMock{},
+				SelectorArg: "123",
+				Finder: shared.NewMockFinder("123", &api.PullRequest{URL: "https://github.com/OWNER/REPO/pull/123", ReviewRequests: api.ReviewRequests{Nodes: []struct{ RequestedReviewer api.RequestedReviewer }{
+					{RequestedReviewer: api.RequestedReviewer{TypeName: "Team", Slug: "core", Organization: struct {
+						Login string `json:"login"`
+					}{Login: "OWNER"}}},
+					{RequestedReviewer: api.RequestedReviewer{TypeName: "User", Login: "monalisa"}},
+				}}}, ghrepo.New("OWNER", "REPO")),
+				Interactive: false,
+				Editable: shared.Editable{
+					Reviewers: shared.EditableSlice{Remove: []string{"monalisa", "OWNER/core"}, Edited: true},
+				},
+				Fetcher: testFetcher{},
+			},
+			httpStubs: func(t *testing.T, reg *httpmock.Registry) {
+				mockRepoMetadata(reg, mockRepoMetadataOptions{reviewers: true})
+				// explicitly assert that no OrganizationTeamList query occurs
+				reg.Exclude(t, httpmock.GraphQL(`query OrganizationTeamList\b`))
+				mockPullRequestUpdate(reg)
+				mockPullRequestRemoveReviewers(reg)
+			},
+			stdout: "https://github.com/OWNER/REPO/pull/123\n",
+		},
+		{
+			name: "non-interactive mutate reviewers with no change to existing team reviewers skips team fetch",
+			input: &EditOptions{
+				Detector:    &fd.EnabledDetectorMock{},
+				SelectorArg: "123",
+				Finder:      shared.NewMockFinder("123", &api.PullRequest{URL: "https://github.com/OWNER/REPO/pull/123"}, ghrepo.New("OWNER", "REPO")),
+				Interactive: false,
+				Editable: shared.Editable{
+					Reviewers: shared.EditableSlice{Add: []string{"monalisa"}, Remove: []string{"hubot"}, Default: []string{"OWNER/core"}, Edited: true},
+				},
+				Fetcher: testFetcher{},
+			},
+			httpStubs: func(t *testing.T, reg *httpmock.Registry) {
+				// reviewers only (users), no team reviewers fetched
+				mockRepoMetadata(reg, mockRepoMetadataOptions{reviewers: true})
+				// explicitly assert that no OrganizationTeamList query occurs
+				reg.Exclude(t, httpmock.GraphQL(`query OrganizationTeamList\b`))
+				mockPullRequestUpdate(reg)
+				mockPullRequestAddReviewers(reg)
+			},
+			stdout: "https://github.com/OWNER/REPO/pull/123\n",
+		},
 		{
 			name: "interactive",
 			input: &EditOptions{
 				Detector:    &fd.EnabledDetectorMock{},
 				SelectorArg: "123",
 				Finder: shared.NewMockFinder("123", &api.PullRequest{
-					URL:                "https://github.com/OWNER/REPO/pull/123",
-					AssignedActorsUsed: true,
+					URL: "https://github.com/OWNER/REPO/pull/123",
 				}, ghrepo.New("OWNER", "REPO")),
 				Interactive: true,
 				Surveyor: testSurveyor{
@@ -560,11 +681,11 @@ func Test_editRun(t *testing.T) {
 				Fetcher:         testFetcher{},
 				EditorRetriever: testEditorRetriever{},
 			},
-			httpStubs: func(reg *httpmock.Registry) {
-				mockRepoMetadata(reg, false)
+			httpStubs: func(t *testing.T, reg *httpmock.Registry) {
+				mockRepoMetadata(reg, mockRepoMetadataOptions{reviewers: true, teamReviewers: true, assignees: true, labels: true, projects: true, milestones: true})
 				mockPullRequestUpdate(reg)
 				mockPullRequestUpdateActorAssignees(reg)
-				mockPullRequestReviewersUpdate(reg)
+				mockPullRequestAddReviewers(reg)
 				mockPullRequestUpdateLabels(reg)
 				mockProjectV2ItemUpdate(reg)
 			},
@@ -576,8 +697,7 @@ func Test_editRun(t *testing.T) {
 				Detector:    &fd.EnabledDetectorMock{},
 				SelectorArg: "123",
 				Finder: shared.NewMockFinder("123", &api.PullRequest{
-					URL:                "https://github.com/OWNER/REPO/pull/123",
-					AssignedActorsUsed: true,
+					URL: "https://github.com/OWNER/REPO/pull/123",
 				}, ghrepo.New("OWNER", "REPO")),
 				Interactive: true,
 				Surveyor: testSurveyor{
@@ -605,8 +725,9 @@ func Test_editRun(t *testing.T) {
 				Fetcher:         testFetcher{},
 				EditorRetriever: testEditorRetriever{},
 			},
-			httpStubs: func(reg *httpmock.Registry) {
-				mockRepoMetadata(reg, true)
+			httpStubs: func(t *testing.T, reg *httpmock.Registry) {
+				// interactive but reviewers not chosen; need everything except reviewers/teams
+				mockRepoMetadata(reg, mockRepoMetadataOptions{assignees: true, labels: true, projects: true, milestones: true})
 				mockPullRequestUpdate(reg)
 				mockPullRequestUpdateActorAssignees(reg)
 				mockPullRequestUpdateLabels(reg)
@@ -619,9 +740,19 @@ func Test_editRun(t *testing.T) {
 			input: &EditOptions{
 				Detector:    &fd.EnabledDetectorMock{},
 				SelectorArg: "123",
-				Finder: shared.NewMockFinder("123", &api.PullRequest{
-					URL:                "https://github.com/OWNER/REPO/pull/123",
-					AssignedActorsUsed: true,
+				Finder: shared.NewMockFinder("123", &api.PullRequest{ // include existing reviewers
+					URL: "https://github.com/OWNER/REPO/pull/123",
+					ReviewRequests: api.ReviewRequests{Nodes: []struct{ RequestedReviewer api.RequestedReviewer }{
+						{RequestedReviewer: api.RequestedReviewer{TypeName: "Team", Slug: "core", Organization: struct {
+							Login string `json:"login"`
+						}{Login: "OWNER"}}},
+						{RequestedReviewer: api.RequestedReviewer{TypeName: "Team", Slug: "external", Organization: struct {
+							Login string `json:"login"`
+						}{Login: "OWNER"}}},
+						{RequestedReviewer: api.RequestedReviewer{TypeName: "User", Login: "monalisa"}},
+						{RequestedReviewer: api.RequestedReviewer{TypeName: "User", Login: "hubot"}},
+						{RequestedReviewer: api.RequestedReviewer{TypeName: "User", Login: "dependabot"}},
+					}},
 				}, ghrepo.New("OWNER", "REPO")),
 				Interactive: true,
 				Surveyor: testSurveyor{
@@ -651,10 +782,10 @@ func Test_editRun(t *testing.T) {
 				Fetcher:         testFetcher{},
 				EditorRetriever: testEditorRetriever{},
 			},
-			httpStubs: func(reg *httpmock.Registry) {
-				mockRepoMetadata(reg, false)
+			httpStubs: func(t *testing.T, reg *httpmock.Registry) {
+				mockRepoMetadata(reg, mockRepoMetadataOptions{reviewers: true, teamReviewers: true, assignees: true, labels: true, projects: true, milestones: true})
 				mockPullRequestUpdate(reg)
-				mockPullRequestReviewersUpdate(reg)
+				mockPullRequestRemoveReviewers(reg)
 				mockPullRequestUpdateActorAssignees(reg)
 				mockPullRequestUpdateLabels(reg)
 				mockProjectV2ItemUpdate(reg)
@@ -667,8 +798,7 @@ func Test_editRun(t *testing.T) {
 				Detector:    &fd.EnabledDetectorMock{},
 				SelectorArg: "123",
 				Finder: shared.NewMockFinder("123", &api.PullRequest{
-					URL:                "https://github.com/OWNER/REPO/pull/123",
-					AssignedActorsUsed: true,
+					URL: "https://github.com/OWNER/REPO/pull/123",
 					AssignedActors: api.AssignedActors{
 						Nodes: []api.Actor{
 							{
@@ -699,7 +829,7 @@ func Test_editRun(t *testing.T) {
 				Fetcher:         testFetcher{},
 				EditorRetriever: testEditorRetriever{},
 			},
-			httpStubs: func(reg *httpmock.Registry) {
+			httpStubs: func(t *testing.T, reg *httpmock.Registry) {
 				reg.Register(
 					httpmock.GraphQL(`query RepositoryAssignableActors\b`),
 					httpmock.StringResponse(`
@@ -746,7 +876,7 @@ func Test_editRun(t *testing.T) {
 				},
 				Fetcher: testFetcher{},
 			},
-			httpStubs: func(reg *httpmock.Registry) {
+			httpStubs: func(t *testing.T, reg *httpmock.Registry) {
 				// Notice there is no call to mockReplaceActorsForAssignable()
 				// and no GraphQL call to RepositoryAssignableActors below.
 				reg.Register(
@@ -774,7 +904,7 @@ func Test_editRun(t *testing.T) {
 
 			reg := &httpmock.Registry{}
 			defer reg.Verify(t)
-			tt.httpStubs(reg)
+			tt.httpStubs(t, reg)
 
 			httpClient := func() (*http.Client, error) { return &http.Client{Transport: reg}, nil }
 			baseRepo := func() (ghrepo.Interface, error) { return ghrepo.New("OWNER", "REPO"), nil }
@@ -791,10 +921,21 @@ func Test_editRun(t *testing.T) {
 	}
 }
 
-func mockRepoMetadata(reg *httpmock.Registry, skipReviewers bool) {
-	reg.Register(
-		httpmock.GraphQL(`query RepositoryAssignableActors\b`),
-		httpmock.StringResponse(`
+type mockRepoMetadataOptions struct {
+	reviewers     bool
+	teamReviewers bool // reviewers must also be true for this to have an effect.
+	assignees     bool
+	labels        bool
+	projects      bool // includes both legacy (v1) and v2
+	milestones    bool
+}
+
+func mockRepoMetadata(reg *httpmock.Registry, opt mockRepoMetadataOptions) {
+	// Assignable actors (users/bots) are fetched when reviewers OR assignees edited with ActorAssignees enabled.
+	if opt.reviewers || opt.assignees {
+		reg.Register(
+			httpmock.GraphQL(`query RepositoryAssignableActors\b`),
+			httpmock.StringResponse(`
 			{ "data": { "repository": { "suggestedActors": {
 				"nodes": [
 					{ "login": "hubot", "id": "HUBOTID", "__typename": "Bot" },
@@ -803,9 +944,11 @@ func mockRepoMetadata(reg *httpmock.Registry, skipReviewers bool) {
 				"pageInfo": { "hasNextPage": false }
 			} } } }
 			`))
-	reg.Register(
-		httpmock.GraphQL(`query RepositoryLabelList\b`),
-		httpmock.StringResponse(`
+	}
+	if opt.labels {
+		reg.Register(
+			httpmock.GraphQL(`query RepositoryLabelList\b`),
+			httpmock.StringResponse(`
 		{ "data": { "repository": { "labels": {
 			"nodes": [
 				{ "name": "feature", "id": "FEATUREID" },
@@ -816,9 +959,11 @@ func mockRepoMetadata(reg *httpmock.Registry, skipReviewers bool) {
 			"pageInfo": { "hasNextPage": false }
 		} } } }
 		`))
-	reg.Register(
-		httpmock.GraphQL(`query RepositoryMilestoneList\b`),
-		httpmock.StringResponse(`
+	}
+	if opt.milestones {
+		reg.Register(
+			httpmock.GraphQL(`query RepositoryMilestoneList\b`),
+			httpmock.StringResponse(`
 		{ "data": { "repository": { "milestones": {
 			"nodes": [
 				{ "title": "GA", "id": "GAID" },
@@ -827,9 +972,11 @@ func mockRepoMetadata(reg *httpmock.Registry, skipReviewers bool) {
 			"pageInfo": { "hasNextPage": false }
 		} } } }
 		`))
-	reg.Register(
-		httpmock.GraphQL(`query RepositoryProjectList\b`),
-		httpmock.StringResponse(`
+	}
+	if opt.projects {
+		reg.Register(
+			httpmock.GraphQL(`query RepositoryProjectList\b`),
+			httpmock.StringResponse(`
 		{ "data": { "repository": { "projects": {
 			"nodes": [
 				{ "name": "Cleanup", "id": "CLEANUPID" },
@@ -838,9 +985,9 @@ func mockRepoMetadata(reg *httpmock.Registry, skipReviewers bool) {
 			"pageInfo": { "hasNextPage": false }
 		} } } }
 		`))
-	reg.Register(
-		httpmock.GraphQL(`query OrganizationProjectList\b`),
-		httpmock.StringResponse(`
+		reg.Register(
+			httpmock.GraphQL(`query OrganizationProjectList\b`),
+			httpmock.StringResponse(`
 		{ "data": { "organization": { "projects": {
 			"nodes": [
 				{ "name": "Triage", "id": "TRIAGEID" }
@@ -848,9 +995,9 @@ func mockRepoMetadata(reg *httpmock.Registry, skipReviewers bool) {
 			"pageInfo": { "hasNextPage": false }
 		} } } }
 		`))
-	reg.Register(
-		httpmock.GraphQL(`query RepositoryProjectV2List\b`),
-		httpmock.StringResponse(`
+		reg.Register(
+			httpmock.GraphQL(`query RepositoryProjectV2List\b`),
+			httpmock.StringResponse(`
 		{ "data": { "repository": { "projectsV2": {
 			"nodes": [
 				{ "title": "CleanupV2", "id": "CLEANUPV2ID" },
@@ -859,9 +1006,9 @@ func mockRepoMetadata(reg *httpmock.Registry, skipReviewers bool) {
 			"pageInfo": { "hasNextPage": false }
 		} } } }
 		`))
-	reg.Register(
-		httpmock.GraphQL(`query OrganizationProjectV2List\b`),
-		httpmock.StringResponse(`
+		reg.Register(
+			httpmock.GraphQL(`query OrganizationProjectV2List\b`),
+			httpmock.StringResponse(`
 		{ "data": { "organization": { "projectsV2": {
 			"nodes": [
 				{ "title": "TriageV2", "id": "TRIAGEV2ID" }
@@ -869,9 +1016,9 @@ func mockRepoMetadata(reg *httpmock.Registry, skipReviewers bool) {
 			"pageInfo": { "hasNextPage": false }
 		} } } }
 		`))
-	reg.Register(
-		httpmock.GraphQL(`query UserProjectV2List\b`),
-		httpmock.StringResponse(`
+		reg.Register(
+			httpmock.GraphQL(`query UserProjectV2List\b`),
+			httpmock.StringResponse(`
 		{ "data": { "viewer": { "projectsV2": {
 			"nodes": [
 				{ "title": "MonalisaV2", "id": "MONALISAV2ID" }
@@ -879,7 +1026,8 @@ func mockRepoMetadata(reg *httpmock.Registry, skipReviewers bool) {
 			"pageInfo": { "hasNextPage": false }
 		} } } }
 		`))
-	if !skipReviewers {
+	}
+	if opt.teamReviewers && opt.reviewers { // teams only relevant if reviewers edited
 		reg.Register(
 			httpmock.GraphQL(`query OrganizationTeamList\b`),
 			httpmock.StringResponse(`
@@ -891,11 +1039,13 @@ func mockRepoMetadata(reg *httpmock.Registry, skipReviewers bool) {
         "pageInfo": { "hasNextPage": false }
       } } } }
 		`))
+	}
+	if opt.reviewers { // Current user fetched only when reviewers requested
 		reg.Register(
 			httpmock.GraphQL(`query UserCurrent\b`),
 			httpmock.StringResponse(`
-		  { "data": { "viewer": { "login": "monalisa" } } }
-		`))
+	  { "data": { "viewer": { "login": "monalisa" } } }
+	`))
 	}
 }
 
@@ -914,9 +1064,15 @@ func mockPullRequestUpdateActorAssignees(reg *httpmock.Registry) {
 	)
 }
 
-func mockPullRequestReviewersUpdate(reg *httpmock.Registry) {
+func mockPullRequestAddReviewers(reg *httpmock.Registry) {
 	reg.Register(
-		httpmock.GraphQL(`mutation PullRequestUpdateRequestReviews\b`),
+		httpmock.REST("POST", "repos/OWNER/REPO/pulls/0/requested_reviewers"),
+		httpmock.StringResponse(`{}`))
+}
+
+func mockPullRequestRemoveReviewers(reg *httpmock.Registry) {
+	reg.Register(
+		httpmock.REST("DELETE", "repos/OWNER/REPO/pulls/0/requested_reviewers"),
 		httpmock.StringResponse(`{}`))
 }
 
